#!/usr/bin/python3

# Test printing

import os
import dogtail.config
import time
dogtail.config.config.logDebugToStdOut = True
dogtail.config.config.logDebugToFile = False

os.environ['LANG']='C'
srcdir = os.environ['srcdir']

from dogtail.procedural import *

run('atril', arguments=' '+srcdir+'/test-page-labels.pdf')

focus.application('atril')
focus.frame('test-page-labels.pdf')
click('File', roleName='menu')
click('Print…', roleName='menu item')
focus.dialog('Print')
click('Pages:', roleName='radio button')
focus.text('Pages')
type('1')
focus.dialog('Print')
click('Page Setup', roleName='page tab', raw=True)
click('All sheets')
click('Odd sheets', roleName='menu item')
click('Preview', roleName='push button')
keyCombo('<Alt><F4>')

# Close atril
focus.application('atril')
click('File', roleName='menu')
click('Close', roleName='menu item')



#!/usr/bin/python3

# This test opens a password encrypted file and tries to unlock it.

import os
os.environ['LANG']='C'
srcdir = os.environ['srcdir']

from dogtail.procedural import *

run('atril', arguments=' '+srcdir+'/test-encrypt.pdf')

# Try an incorrect password first
focus.application('atril')
type('wrong password')
click('Unlock Document', roleName='push button')
focus.dialog('Enter password')
click('Cancel', roleName='push button')

# Try again with the correct password
focus.frame('test-encrypt.pdf — Password Required')
click('Unlock Document', roleName='push button')
focus.dialog('Enter password')
type('Foo')
click('Unlock Document', roleName='push button')

# Close atril
focus.application('atril')
click('File', roleName='menu')
click('Close', roleName='menu item')



#!/usr/bin/python3

# This test tries document reload action.

import os
os.environ['LANG']='C'
srcdir = os.environ['srcdir']

from dogtail.procedural import *

run('atril', arguments=' '+srcdir+'/test-links.pdf')

# Reload document a few times
for i in range(1,6):
    focus.application('atril')
    click('View', roleName='menu')
    click('Reload', roleName='menu item')

# Close atril
focus.application('atril')
click('File', roleName='menu')
click('Close', roleName='menu item')



#!/usr/bin/python3

# This test opens the interface and just clicks around a bit.

import os
import dogtail.config
dogtail.config.config.logDebugToStdOut = True
dogtail.config.config.logDebugToFile = False

from dogtail.procedural import *

os.environ['LANG']='C'
run('atril')

# Test file->open
focus.application('atril')
click('File', roleName='menu')
click('Open…', roleName='menu item')
click('Cancel', roleName='push button')

# Toolbar editor
focus.application('atril')
click('Edit', roleName='menu')
click('Toolbar', roleName='menu item')
click('Close', roleName='push button')

# About dialog
focus.application('atril')
click('Help', roleName='menu')
click('About', roleName='menu item')
click('Credits', roleName='toggle button')
click('Credits', roleName='toggle button')
click('Close', roleName='push button')

# Close atril
focus.application('atril')
click.menu('File')
click('Close', roleName='menu item')



#!/usr/bin/python3

# Test printing

import os
import dogtail.config
dogtail.config.config.logDebugToStdOut = True
dogtail.config.config.logDebugToFile = False

os.environ['LANG']='C'
srcdir = os.environ['srcdir']

from dogtail.procedural import *

recent_used = os.path.expanduser('~/.local/share/recently-used.xbel')
recent_used_orig = recent_used + '.orig'

ps_file = os.path.expanduser('~/output.ps')

if os.path.isfile(recent_used):
    os.rename(recent_used, recent_used_orig)

if os.path.exists(ps_file):
    os.unlink(ps_file)

run('atril', arguments=' '+srcdir+'/test-page-labels.pdf')

focus.application('atril')
click('File', roleName='menu')
click('Print…', roleName='menu item')

click('Print to File', roleName='table cell', raw=True)
click('Postscript', roleName='radio button', raw=True)
click('Print', roleName='push button')

statinfo = os.stat (ps_file)
if statinfo.st_size > 100000:
    exit(1)
os.unlink (ps_file)

# Close atril
focus.application('atril')
click('File', roleName='menu')
click('Close', roleName='menu item')

if os.path.isfile(recent_used_orig):
    os.rename(recent_used_orig, recent_used)



#!/usr/bin/python3

# This test opens a file with wrong extenstion.

import os
os.environ['LANG']='C'
srcdir = os.environ['srcdir']

from dogtail.procedural import *

run('atril', arguments=' '+srcdir+'/test-mime.bin')

# Close atril
focus.application('atril')
click('File', roleName='menu')
click('Close', roleName='menu item')
